@@ -299,8 +299,8 @@ class FaasJobManager:
         self.firestore.upsert(self.remaining_job_collection_name, op_id, {}, doc_ref)
         return (self.op_id, {})
 
-    def _insert_job_done(self, job_done_collection: str, job_args: dict, status: FaasOpState) -> Tuple[str, dict]:
-        data = {"args": job_args, "status": status.value}
+    def _insert_job_done(self, job_done_collection: str, job_args: dict, job_result: dict, status: FaasOpState) -> Tuple[str, dict]:
+        data = {"args": job_args, "result": job_result, "status": status.value}
         self.firestore.upsert(job_done_collection, self.job_id, data, None)
         return (self.op_id, data)
 
@@ -401,7 +401,7 @@ class FaasJobManager:
         """
 
         if req.job_done_collection is not None:
-            self._insert_job_done(req.job_done_collection, root_job.args, status)
+            self._insert_job_done(req.job_done_collection, root_job.args, root_job.result, status)
 
     def add_job(self, trigger: FaasJobTrigger):
         """Increments total jobs counter on FaasJob metadata, add
